@@ -2,6 +2,7 @@ from ._tksheet_vars import *
 from ._tksheet_other_classes import *
 
 from itertools import islice, accumulate, chain, cycle, repeat
+from collections import defaultdict
 from math import floor, ceil
 import bisect
 import pickle
@@ -66,16 +67,16 @@ class RowIndex(tk.Canvas):
         self.currently_resizing_height = False
         self.ri_rc_popup_menu = None
         
-        self.disp_text = {}
-        self.disp_high = {}
+        self.disp_text = defaultdict(set)
+        self.disp_high = defaultdict(set)
         self.disp_grid = {}
         self.disp_fill_sels = {}
         self.disp_bord_sels = {}
         self.disp_resize_lines = {}
         self.disp_dropdown = {}
         self.disp_checkbox = {}
-        self.hidd_text = {}
-        self.hidd_high = {}
+        self.hidd_text = defaultdict(set)
+        self.hidd_high = defaultdict(set)
         self.hidd_grid = {}
         self.hidd_fill_sels = {}
         self.hidd_bord_sels = {}
@@ -248,6 +249,7 @@ class RowIndex(tk.Canvas):
             x = self.canvasx(event.x)
             y = self.canvasy(event.y)
             mouse_over_resize = False
+            mouse_over_selected = False
             if self.height_resizing_enabled and not mouse_over_resize:
                 r = self.check_mouse_position_height_resizers(x, y)
                 if r is not None:
@@ -268,6 +270,10 @@ class RowIndex(tk.Canvas):
                 except:
                     self.rsz_w = None
             if not mouse_over_resize:
+                if self.MT.row_selected(self.MT.identify_row(event, allow_end = False)):
+                    self.config(cursor = "hand2")
+                    mouse_over_selected = True
+            if not mouse_over_resize and not mouse_over_selected:
                 self.MT.reset_mouse_motion_creations()
         if self.extra_motion_func is not None:
             self.extra_motion_func(event)
@@ -337,10 +343,19 @@ class RowIndex(tk.Canvas):
         elif self.row_selection_enabled and self.rsz_h is None and self.rsz_w is None:
             r = self.MT.identify_row(y = event.y)
             if r < len(self.MT.row_positions) - 1:
-                if self.MT.single_selection_enabled:
-                    self.select_row(r, redraw = True)
-                elif self.MT.toggle_selection_enabled:
-                    self.toggle_select_row(r, redraw = True)
+                if self.MT.row_selected(r):
+                    drow = r if self.MT.all_rows_displayed else self.MT.displayed_rows[r]
+                    if ((drow in self.cell_options and 'dropdown' in self.cell_options[drow] and event.x < self.current_width and event.x > self.current_width - self.MT.txt_h - 4) or
+                        (drow in self.cell_options and 'checkbox' in self.cell_options[drow] and event.x < self.current_width + self.MT.txt_h + 5)) and y < self.MT.row_positions[r] + self.MT.txt_h + 5:
+                        pass
+                    else:
+                        self.dragged_row = r
+                else:
+                    self.being_drawn_rect = (r, 0, r + 1, len(self.MT.col_positions) - 1, "rows")
+                    if self.MT.single_selection_enabled:
+                        self.select_row(r, redraw = True)
+                    elif self.MT.toggle_selection_enabled:
+                        self.toggle_select_row(r, redraw = True)
         if self.extra_b1_press_func is not None:
             self.extra_b1_press_func(event)
     
@@ -349,7 +364,7 @@ class RowIndex(tk.Canvas):
         if self.height_resizing_enabled and self.rsz_h is not None and self.currently_resizing_height:
             y = self.canvasy(event.y)
             size = y - self.MT.row_positions[self.rsz_h - 1]
-            if not size <= self.MT.min_rh and size < self.max_rh:
+            if not size < self.MT.min_rh and size < self.max_rh:
                 self.delete_resize_lines()
                 self.MT.delete_resize_lines()
                 line2y = self.MT.row_positions[self.rsz_h - 1]
@@ -413,6 +428,7 @@ class RowIndex(tk.Canvas):
                 self.create_resize_line(0, ypos, self.current_width, ypos, width = 3, fill = self.drag_and_drop_bg, tag = "dd")
                 self.MT.create_resize_line(x1, ypos, x2, ypos, width = 3, fill = self.drag_and_drop_bg, tag = "dd")
         elif self.MT.drag_selection_enabled and self.row_selection_enabled and self.rsz_h is None and self.rsz_w is None:
+            need_redraw = False
             end_row = self.MT.identify_row(y = event.y)
             currently_selected = self.MT.currently_selected()
             if end_row < len(self.MT.row_positions) - 1 and currently_selected:
@@ -425,6 +441,7 @@ class RowIndex(tk.Canvas):
                         rect = (end_row, 0, start_row + 1, len(self.MT.col_positions) - 1, "rows")
                         func_event = tuple(range(end_row, start_row + 1))
                     if self.being_drawn_rect != rect:
+                        need_redraw = True
                         self.MT.delete_selection_rects(delete_current = False)
                         self.MT.create_selected(*rect)
                         self.being_drawn_rect = rect
@@ -438,6 +455,7 @@ class RowIndex(tk.Canvas):
                 except:
                     pass
                 self.check_yview()
+                need_redraw = True
             elif event.y < 0 and self.canvasy(self.winfo_height()) > 0 and ycheck and ycheck[0] > 0:
                 try:
                     self.yview_scroll(-1, "units")
@@ -445,7 +463,9 @@ class RowIndex(tk.Canvas):
                 except:
                     pass
                 self.check_yview()
-            self.MT.main_table_redraw_grid_and_text(redraw_header = False, redraw_row_index = True)
+                need_redraw = True
+            if need_redraw:
+                self.MT.main_table_redraw_grid_and_text(redraw_header = False, redraw_row_index = True)
         if self.extra_b1_motion_func is not None:
             self.extra_b1_motion_func(event)
 
@@ -457,6 +477,10 @@ class RowIndex(tk.Canvas):
             self.MT.set_yviews("moveto", 1)
             
     def b1_release(self, event = None):
+        if self.being_drawn_rect is not None:
+            to_sel = tuple(self.being_drawn_rect)
+            self.being_drawn_rect = None
+            self.MT.create_selected(*to_sel)
         self.MT.bind("<MouseWheel>", self.MT.mousewheel)
         if self.height_resizing_enabled and self.rsz_h is not None and self.currently_resizing_height:
             self.currently_resizing_height = False
@@ -530,20 +554,18 @@ class RowIndex(tk.Canvas):
                 drow = r if self.MT.all_rows_displayed else self.MT.displayed_rows[r]
                 canvasy = self.canvasy(event.y)
                 if ((drow in self.cell_options and 'dropdown' in self.cell_options[drow] and event.x < self.current_width and event.x > self.current_width - self.MT.txt_h - 4) or
-                    (drow in self.cell_options and 'checkbox' in self.cell_options[drow] and event.x < self.current_width + self.MT.txt_h + 5)):
-                    if canvasy < self.MT.row_positions[r] + self.MT.txt_h + 5:
+                    (drow in self.cell_options and 'checkbox' in self.cell_options[drow] and event.x < self.MT.txt_h + 5)):
+                    if canvasy < self.MT.row_positions[r] + self.MT.txt_h:
                         self.open_cell(event)
             else:
                 self.mouseclick_outside_editor_or_dropdown()
             self.b1_pressed_loc = None
-            self.closed_dropdown = None
-                        
+            self.closed_dropdown = None    
         self.dragged_row = None
         self.currently_resizing_width = False
         self.currently_resizing_height = False
         self.rsz_w = None
         self.rsz_h = None
-        self.being_drawn_rect = None
         self.mouse_motion(event)
         if self.extra_b1_release_func is not None:
             self.extra_b1_release_func(event)
@@ -861,32 +883,41 @@ class RowIndex(tk.Canvas):
         return tf, redrawn
 
     def redraw_highlight(self, x1, y1, x2, y2, fill, outline, tag):
-        if self.hidd_high:
-            t, sh = self.hidd_high.popitem()
-            self.coords(t, x1, y1, x2, y2)
-            if sh:
-                self.itemconfig(t, fill = fill, outline = outline, tag = tag)
+        config = (fill, outline)
+        coords = (x1, y1, x2, y2)
+        k = None
+        if config in self.hidd_high:
+            k = config
+            iid, showing = self.hidd_high[k].pop()
+            if all(int(crd1) == int(crd2) for crd1, crd2 in zip(self.coords(iid), coords)):
+                option = 0 if showing else 2
             else:
-                self.itemconfig(t, fill = fill, outline = outline, tag = tag, state = "normal")
-            self.lift(t)
-            self.disp_high[t] = True
-        else:
-            self.disp_high[self.create_rectangle(x1, y1, x2, y2, fill = fill, outline = outline, tag = tag)] = True
-        return True
+                option = 1 if showing else 3
 
-    def redraw_text(self, x, y, text, fill, font, anchor, tag):
-        if self.hidd_text:
-            t, sh = self.hidd_text.popitem()
-            self.coords(t, x, y)
-            if sh:
-                self.itemconfig(t, text = text, fill = fill, font = font, anchor = anchor)
+        elif self.hidd_high:
+            k = next(iter(self.hidd_high))
+            iid, showing = self.hidd_high[k].pop()
+            if all(int(crd1) == int(crd2) for crd1, crd2 in zip(self.coords(iid), coords)):
+                option = 2 if showing else 3
             else:
-                self.itemconfig(t, text = text, fill = fill, font = font, anchor = anchor, state = "normal")
-            self.lift(t)
+                option = 3
+            
         else:
-            t = self.create_text(x, y, text = text, fill = fill, font = font, anchor = anchor, tag = tag)
-        self.disp_text[t] = True
-        return t
+            iid, showing, option = self.create_rectangle(coords, fill = fill, outline = outline, tag = tag), 1, 4
+
+        if option in (1, 3):
+            self.coords(iid, coords)
+        if option in (2, 3):
+            if showing:
+                self.itemconfig(iid, fill = fill, outline = outline)
+            else:
+                self.itemconfig(iid, fill = fill, outline = outline, tag = tag, state = "normal")
+        
+        if k is not None and not self.hidd_high[k]:
+            del self.hidd_high[k]
+
+        self.disp_high[config].add(DrawnItem(iid = iid, showing = 1))
+        return True
 
     def redraw_gridline(self, points, fill, width, tag):
         if self.hidd_grid:
@@ -952,11 +983,11 @@ class RowIndex(tk.Canvas):
         self.disp_checkbox[t] = True
         if draw_check:
             # draw filled box
-            x1 = x1 + 2
-            y1 = y1 + 2
-            x2 = x2 - 1
-            y2 = y2 - 1
-            points = self.MT.get_checkbox_points(x1, y1, x2, y2)
+            x1 = x1 + 4
+            y1 = y1 + 4
+            x2 = x2 - 3
+            y2 = y2 - 3
+            points = self.MT.get_checkbox_points(x1, y1, x2, y2, radius = 4)
             if self.hidd_checkbox:
                 t, sh = self.hidd_checkbox.popitem()
                 self.coords(t, points)
@@ -969,41 +1000,23 @@ class RowIndex(tk.Canvas):
                 t = self.create_polygon(points, fill = fill, outline = outline, tag = tag, smooth = True)
             self.disp_checkbox[t] = True
 
-            # draw one line of X
-            if self.hidd_grid:
-                t, sh = self.hidd_grid.popitem()
-                self.coords(t, x1 + 2, y1 + 2, x2 - 2, y2 - 2)
-                if sh:
-                    self.itemconfig(t, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2)
-                else:
-                    self.itemconfig(t, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2, tag = tag, state = "normal")
-                self.lift(t)
-            else:
-                t = self.create_line(x1 + 2, y1 + 2, x2 - 2, y2 - 2, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2, tag = tag)
-            self.disp_grid[t] = True
-
-            # draw other line of X
-            if self.hidd_grid:
-                t, sh = self.hidd_grid.popitem()
-                self.coords(t, x2 - 2, y1 + 2, x1 + 2, y2 - 2)
-                if sh:
-                    self.itemconfig(t, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2)
-                else:
-                    self.itemconfig(t, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2, tag = tag, state = "normal")
-                self.lift(t)
-            else:
-                t = self.create_line(x2 - 2, y1 + 2, x1 + 2, y2 - 2, fill = self.get_widget_bg_fg(r)[0], capstyle = tk.ROUND, joinstyle = tk.ROUND, width = 2, tag = tag)
-            self.disp_grid[t] = True
-
     def redraw_grid_and_text(self, last_row_line_pos, y1, y_stop, start_row, end_row, y2, x1, x_stop, selected_rows, selected_cols, actual_selected_rows):
         self.configure(scrollregion = (0,
                                        0,
                                        self.current_width,
                                        last_row_line_pos + self.MT.empty_vertical))
-        self.hidd_text.update(self.disp_text)
-        self.disp_text = {}
-        self.hidd_high.update(self.disp_high)
-        self.disp_high = {}
+        for k, v in self.disp_text.items():
+            if k in self.hidd_text:
+                self.hidd_text[k] = self.hidd_text[k] | self.disp_text[k]
+            else:
+                self.hidd_text[k] = v
+        self.disp_text = defaultdict(set)
+        for k, v in self.disp_high.items():
+            if k in self.hidd_high:
+                self.hidd_high[k] = self.hidd_high[k] | self.disp_high[k]
+            else:
+                self.hidd_high[k] = v
+        self.disp_high = defaultdict(set)
         self.hidd_grid.update(self.disp_grid)
         self.disp_grid = {}
         self.hidd_dropdown.update(self.disp_dropdown)
@@ -1037,6 +1050,7 @@ class RowIndex(tk.Canvas):
         sb = y2 + 2
         c_2 = self.index_selected_cells_bg if self.index_selected_cells_bg.startswith("#") else Color_Map_[self.index_selected_cells_bg]
         c_3 = self.index_selected_rows_bg if self.index_selected_rows_bg.startswith("#") else Color_Map_[self.index_selected_rows_bg]
+        font = self.MT._font
         for r in range(start_row, end_row - 1):
             fr = self.MT.row_positions[r]
             sr = self.MT.row_positions[r + 1]
@@ -1051,11 +1065,11 @@ class RowIndex(tk.Canvas):
             tf, dd_drawn = self.redraw_highlight_get_text_fg(fr, sr, r, c_2, c_3, selected_rows, selected_cols, actual_selected_rows, drow)
             
             if r in self.cell_options and 'align' in self.cell_options[r]:
-                cell_alignment = self.cell_options[r]['align']
+                align = self.cell_options[r]['align']
             else:
-                cell_alignment = self.align
+                align = self.align
                 
-            if cell_alignment == "w":
+            if align == "w":
                 x = 3
                 if r in self.cell_options and 'dropdown' in self.cell_options[r]:
                     mw = self.current_width - self.MT.txt_h - 2
@@ -1065,7 +1079,7 @@ class RowIndex(tk.Canvas):
                 else:
                     mw = self.current_width - 2
 
-            elif cell_alignment == "e":
+            elif align == "e":
                 if r in self.cell_options and 'dropdown' in self.cell_options[r]:
                     mw = self.current_width - self.MT.txt_h - 2
                     x = self.current_width - 5 - self.MT.txt_h
@@ -1076,7 +1090,7 @@ class RowIndex(tk.Canvas):
                     mw = self.current_width - 2
                     x = self.current_width - 3
 
-            elif cell_alignment == "center":
+            elif align == "center":
                 if r in self.cell_options and 'dropdown' in self.cell_options[r]:
                     mw = self.current_width - self.MT.txt_h - 2
                     x = ceil((self.current_width - self.MT.txt_h) / 2)
@@ -1089,21 +1103,28 @@ class RowIndex(tk.Canvas):
 
             if r in self.cell_options and 'checkbox' in self.cell_options[r]:
                 if mw > + 2:
-                    box_w = self.MT.txt_h + 2
-                    if cell_alignment == "w":
-                        x += box_w
-                    elif cell_alignment == "center":
+                    box_w = self.MT.txt_h + 1
+                    mw -= box_w
+                    if align == "w":
+                        x += box_w + 1
+                    elif align == "center":
                         x += ceil(box_w / 2) + 1
-                    mw = mw - box_w - 1
+                        mw -= 1
+                    else:
+                        mw -= 3
+                    try:
+                        draw_check = self.MT._row_index[r] if isinstance(self.MT._row_index, (list, tuple)) else self.MT.data[r][self.MT._row_index]
+                    except:
+                        draw_check = False
                     self.redraw_checkbox(r,
-                                         0,
+                                         2,
                                          fr + 2,
-                                         self.MT.txt_h + 2,
-                                         fr + self.MT.txt_h + 4,
+                                         self.MT.txt_h + 3,
+                                         fr + self.MT.txt_h + 3,
                                          fill = tf if self.cell_options[r]['checkbox']['state'] == "normal" else self.index_grid_fg,
                                          outline = "",
                                          tag = "cb",
-                                         draw_check = self.MT._row_index[r] if isinstance(self.MT._row_index, (list, tuple)) else self.MT.data[r][self.MT._row_index])
+                                         draw_check = draw_check)
 
             try:
                 if r in self.cell_options and 'checkbox' in self.cell_options[r]:
@@ -1122,11 +1143,8 @@ class RowIndex(tk.Canvas):
                     lns = (f"{r + 1}", )
                 else:
                     lns = (f"{r + 1} {num2alpha(r)}", )
-
             y = fr + self.MT.fl_ins
-            if cell_alignment == "center":
-                if mw <= 5:
-                    continue
+            if mw > 5:
                 start_line = int((y1 - y) / self.MT.xtra_lines_increment) - 1
                 if start_line > 0:
                     start_line += 1
@@ -1136,87 +1154,86 @@ class RowIndex(tk.Canvas):
                 if len(lns) > start_line:
                     for txt in islice(lns, start_line, None):
                         if y + self.MT.half_txt_h - 1 > y1:
-                            t = self.redraw_text(x, y, text = txt, fill = tf, font = self.MT._font, anchor = cell_alignment, tag = "t")
-                            wd = self.bbox(t)
+                            config = TextCfg(txt, tf, font, align)
+                            k = None
+                            if config in self.hidd_text:
+                                k = config
+                                iid, showing = self.hidd_text[k].pop()
+                                cc1, cc2 = self.coords(iid)
+                                if (int(cc1) == int(x) and
+                                    int(cc2) == int(y)):
+                                    option = 0 if showing else 2
+                                else:
+                                    option = 1 if showing else 3
+                            elif self.hidd_text:
+                                k = next(iter(self.hidd_text))
+                                iid, showing = self.hidd_text[k].pop()
+                                cc1, cc2 = self.coords(iid)
+                                if (int(cc1) == int(x) and
+                                    int(cc2) == int(y)):
+                                    option = 2 if showing else 3
+                                else:
+                                    option = 3
+                            else:
+                                iid, showing, option = self.create_text(x, y, text = txt, fill = tf, font = font, anchor = align, tag = "t"), 1, 4
+                            if option in (1, 3):
+                                self.coords(iid, x, y)
+                            if option in (2, 3):
+                                if showing:
+                                    self.itemconfig(iid, text = txt, fill = tf, font = font, anchor = align)
+                                else:
+                                    self.itemconfig(iid, text = txt, fill = tf, font = font, anchor = align, state = "normal")
+                            if k is not None and not self.hidd_text[k]:
+                                del self.hidd_text[k]
+                            wd = self.bbox(iid)
                             wd = wd[2] - wd[0]
                             if wd > mw:
-                                tl = len(txt)
-                                tmod = ceil((tl - int(tl * (mw / wd))) / 2)
-                                txt = txt[tmod - 1:-tmod]
-                                self.itemconfig(t, text = txt)
-                                wd = self.bbox(t)
-                                self.c_align_cyc = cycle(self.centre_alignment_text_mod_indexes)
-                                while wd[2] - wd[0] > mw:
-                                    txt = txt[next(self.c_align_cyc)]
-                                    self.itemconfig(t, text = txt)
-                                    wd = self.bbox(t)
-                                self.coords(t, x, y)
-                        y += self.MT.xtra_lines_increment
-                        if y + self.MT.half_txt_h - 1 > sr:
-                            break
-
-            elif cell_alignment == "e":
-                if mw <= 5:
-                    continue
-                start_line = int((y1 - y) / self.MT.xtra_lines_increment) - 1
-                if start_line > 0:
-                    start_line += 1
-                    y += (start_line * self.MT.xtra_lines_increment)
-                elif start_line < 0:
-                    start_line = 0
-                if len(lns) > start_line:
-                    for txt in islice(lns, start_line, None):
-                        if y + self.MT.half_txt_h - 1 > y1:
-                            t = self.redraw_text(x, y, text = txt, fill = tf, font = self.MT._font, anchor = cell_alignment, tag = "t")
-                            wd = self.bbox(t)
-                            wd = wd[2] - wd[0]
-                            if wd > mw:
-                                txt = txt[len(txt) - int(len(txt) * (mw / wd)):]
-                                self.itemconfig(t, text = txt)
-                                wd = self.bbox(t)
-                                while wd[2] - wd[0] > mw:
-                                    txt = txt[1:]
-                                    self.itemconfig(t, text = txt)
-                                    wd = self.bbox(t)
-                        y += self.MT.xtra_lines_increment
-                        if y + self.MT.half_txt_h - 1 > sr:
-                            break
-
-            elif cell_alignment == "w":
-                if mw <= 5:
-                    continue
-                start_line = int((y1 - y) / self.MT.xtra_lines_increment) - 1
-                if start_line > 0:
-                    start_line += 1
-                    y += (start_line * self.MT.xtra_lines_increment)
-                elif start_line < 0:
-                    start_line = 0
-                if len(lns) > start_line:
-                    for txt in islice(lns, start_line, None):
-                        if y + self.MT.half_txt_h - 1 > y1:
-                            t = self.redraw_text(x, y, text = txt, fill = tf, font = self.MT._font, anchor = cell_alignment, tag = "t")
-                            if drow in self.cell_options and 'dropdown' in self.cell_options[drow]:
-                                wd = self.bbox(t)
-                                wd = wd[2] - wd[0]
-                                if wd > mw:
-                                    nl = int(len(txt) * (mw / wd))
-                                    self.itemconfig(t, text = txt[:nl])
-                                    wd = self.bbox(t)
+                                if align == "w" and drow in self.cell_options and 'dropdown' in self.cell_options[drow]:
+                                    txt = txt[:int(len(txt) * (mw / wd))]
+                                    self.itemconfig(iid, text = txt)
+                                    wd = self.bbox(iid)
                                     while wd[2] - wd[0] > mw:
-                                        nl -= 1
-                                        self.dchars(t, nl)
-                                        wd = self.bbox(t)
-                        y += self.MT.xtra_lines_increment
-                        if y + self.MT.half_txt_h - 1 > sr:
-                            break
-        for t, sh in self.hidd_text.items():
-            if sh:
-                self.itemconfig(t, state = "hidden")
-                self.hidd_text[t] = False
-        for t, sh in self.hidd_high.items():
-            if sh:
-                self.itemconfig(t, state = "hidden")
-                self.hidd_high[t] = False
+                                        txt = txt[:-1]
+                                        self.itemconfig(iid, text = txt)
+                                        wd = self.bbox(iid)
+                                elif align == "e" and drow in self.cell_options and 'checkbox' in self.cell_options[drow]:
+                                    txt = txt[len(txt) - int(len(txt) * (mw / wd)):]
+                                    self.itemconfig(iid, text = txt)
+                                    wd = self.bbox(iid)
+                                    while wd[2] - wd[0] > mw:
+                                        txt = txt[1:]
+                                        self.itemconfig(iid, text = txt)
+                                        wd = self.bbox(iid)
+                                elif align == "center":
+                                    tmod = ceil((len(txt) - int(len(txt) * (mw / wd))) / 2)
+                                    txt = txt[tmod - 1:-tmod]
+                                    self.itemconfig(iid, text = txt)
+                                    wd = self.bbox(iid)
+                                    self.c_align_cyc = cycle(self.centre_alignment_text_mod_indexes)
+                                    while wd[2] - wd[0] > mw:
+                                        txt = txt[next(self.c_align_cyc)]
+                                        self.itemconfig(iid, text = txt)
+                                        wd = self.bbox(iid)
+                                    self.coords(iid, x, y)
+                                self.disp_text[config._replace(txt = txt)].add(DrawnItem(iid = iid, showing = 1))
+                            else:
+                                self.disp_text[config].add(DrawnItem(iid = iid, showing = 1))
+                            y += self.MT.xtra_lines_increment
+                            if y + self.MT.half_txt_h - 1 > sr:
+                                break
+        self.tag_raise("t")
+        for cfg, set_ in self.hidd_text.items():
+            for namedtup in tuple(set_):
+                if namedtup.showing:
+                    self.itemconfig(namedtup.iid, state = "hidden")
+                    self.hidd_text[cfg].discard(namedtup)
+                    self.hidd_text[cfg].add(namedtup._replace(showing = 0))
+        for cfg, set_ in self.hidd_high.items():
+            for namedtup in tuple(set_):
+                if namedtup.showing:
+                    self.itemconfig(namedtup.iid, state = "hidden")
+                    self.hidd_high[cfg].discard(namedtup)
+                    self.hidd_high[cfg].add(namedtup._replace(showing = 0))
         for t, sh in self.hidd_grid.items():
             if sh:
                 self.itemconfig(t, state = "hidden")
@@ -1269,8 +1286,6 @@ class RowIndex(tk.Canvas):
                     text = f"{self.MT.data[self.MT._row_index][drow]}"
                 except:
                     text = ""
-            if self.MT.cell_auto_resize_enabled:
-                self.set_row_height_run_binding(r)
         elif event is not None and ((hasattr(event, 'keysym') and event.keysym == 'BackSpace') or
                                   event.keycode in (8, 855638143)
                                   ):
@@ -1294,6 +1309,8 @@ class RowIndex(tk.Canvas):
             else:
                 text = text if isinstance(text, str) else f"{text}"
         text = "" if text is None else text
+        if self.MT.cell_auto_resize_enabled:
+            self.set_row_height_run_binding(r)
         self.select_row(r = r, keep_other_selections = True, redraw = not dropdown)
         self.create_text_editor(r = r, text = text, set_data_ref_on_destroy = True, dropdown = dropdown)
         return True
@@ -1302,10 +1319,10 @@ class RowIndex(tk.Canvas):
     def get_cell_align(self, r):
         drow = r if self.MT.all_rows_displayed else self.MT.displayed_rows[r]
         if drow in self.cell_options and 'align' in self.cell_options[drow]:
-            cell_alignment = self.cell_options[drow]['align']
+            align = self.cell_options[drow]['align']
         else:
-            cell_alignment = self.align
-        return cell_alignment
+            align = self.align
+        return align
 
     # r is displayed row
     def create_text_editor(self,
@@ -1599,8 +1616,6 @@ class RowIndex(tk.Canvas):
         if self.cell_options[drow]['dropdown']['state'] == "normal":
             if not self.edit_cell_(r = r, dropdown = True, event = event):
                 return
-        #bg, fg = self.get_widget_bg_fg(drow)
-        bg, fg = self.index_bg, self.index_fg
         win_h, anchor = self.get_dropdown_height_anchor(drow)
         window = self.MT.parentframe.dropdown_class(self.MT.winfo_toplevel(),
                                                     r,
@@ -1608,9 +1623,11 @@ class RowIndex(tk.Canvas):
                                                     width = self.current_width,
                                                     height = win_h,
                                                     font = self.MT._font,
-                                                    bg = bg,
-                                                    fg = fg,
-                                                    outline_color = fg,
+                                                    colors = {'bg': self.MT.popup_menu_bg, 
+                                                              'fg': self.MT.popup_menu_fg, 
+                                                              'highlight_bg': self.MT.popup_menu_highlight_bg,
+                                                              'highlight_fg': self.MT.popup_menu_highlight_fg},
+                                                    outline_color = self.MT.popup_menu_fg,
                                                     values = self.cell_options[drow]['dropdown']['values'],
                                                     hide_dropdown_window = self.hide_dropdown_window,
                                                     arrowkey_RIGHT = self.MT.arrowkey_RIGHT,
